import React, { useEffect } from 'react';
import { Bot, Rocket, Target, Globe, ArrowRight, Phone, Layout, Home, CalendarPlus, BrainCircuit } from 'lucide-react';
import { Link } from 'react-router-dom';
import Footer from '../components/Footer';

const Demo = () => {
  useEffect(() => {
    document.title = 'AI Communication Demos - Try Our Smart Automation | Sales Assist AI';
    // Update meta description
    const metaDescription = document.querySelector('meta[name="description"]');
    if (metaDescription) {
      metaDescription.setAttribute('content', 'Experience our AI-powered communication platform through interactive demos. Try our intelligent chat, lead qualification, and phone automation systems in action.');
    }
    // Scroll to top when component mounts
    window.scrollTo({ top: 0, behavior: 'smooth' });
  }, []);

  return (
      <div>
        <div className="min-h-screen bg-gradient-to-b from-white via-primary-50/30 to-white">
        <div className="container pt-32 pb-8">
          <div className="text-center mb-16">
            <div className="inline-flex items-center gap-2 px-4 py-2 rounded-full bg-primary-50 border border-primary-100 mb-4">
              <div className="p-1 bg-gradient-to-r from-primary-500 to-primary-600 rounded-full">
                <Rocket className="w-4 h-4 text-white" />
              </div>
              <span className="text-sm font-medium text-primary-700">
                SALES ASSIST AI DEMO
              </span>
            </div>
            
            <h1 className="text-4xl font-bold text-secondary-900 mb-4">
              Experience AI-Powered
              <span className="block text-gradient mt-2">Customer Communication</span>
            </h1>
            <p className="text-xl text-secondary-600 max-w-2xl mx-auto">
              Interactive demos of our AI-powered marketing and automation solutions
            </p>
          </div>

          <div className="max-w-4xl mx-auto">
            <div className="grid gap-8">
              {/* Featured Demo Section */}
              <div
                className="group relative bg-white/80 backdrop-blur-sm rounded-3xl p-8 border border-primary-100/50 shadow-soft hover:shadow-lg transition-all overflow-hidden"
              >
                <div className="absolute top-0 right-0 px-3 py-1.5 bg-primary-50 text-primary-700 text-sm font-medium rounded-bl-lg border-l border-b border-primary-100">
                  Basic Preview
                </div>
                <div className="grid gap-4">
                  <a 
                    href="/platform-demo"
                    className="flex items-start gap-6 group/link"
                  >
                    <div className="w-16 h-16 rounded-xl bg-primary-50 flex items-center justify-center group-hover/link:scale-105 transition-transform">
                      <Layout className="w-8 h-8 text-primary-600" />
                    </div>
                    <div className="flex-1">
                      <div className="flex items-center justify-between">
                        <h3 className="text-2xl font-semibold text-secondary-900">Platform Demo</h3>
                        <ArrowRight className="w-5 h-5 text-primary-600 group-hover:translate-x-1 transition-transform" />
                      </div>
                      <p className="text-secondary-600 mt-2">
                        Get a quick overview of our platform's core features. Book a personalized demo for a comprehensive tour tailored to your business needs.
                      </p>
                    </div>
                  </a>
                  <div className="pt-4 border-t border-primary-100/50">
                    <Link
                      to="/book-demo"
                      className="inline-flex items-center gap-1.5 text-primary-600 font-medium hover:text-primary-700"
                    >
                      <CalendarPlus className="w-4 h-4" />
                      Book a Personalized Demo
                    </Link>
                  </div>
                </div>
              </div>

              {/* Interactive Demos List */}
              <div className="space-y-4">
              <a 
                href="/ai-lead-demo"
                className="group block bg-white/80 backdrop-blur-sm rounded-2xl p-6 border border-primary-100/50 shadow-soft hover:shadow-lg hover:-translate-y-0.5 transition-all"
                style={{ position: 'relative' }}
              >
                <div className="absolute top-0 right-0 px-3 py-1.5 bg-primary-50 text-primary-700 text-sm font-medium rounded-bl-lg border-l border-b border-primary-100">
                  Interactive Demo
                </div>
                <div className="flex items-start gap-6">
                  <div className="w-16 h-16 rounded-xl bg-primary-50 flex items-center justify-center group-hover:scale-105 transition-transform">
                    <BrainCircuit className="w-8 h-8 text-primary-600" />
                  </div>
                  <div className="flex-1">
                    <div className="flex items-center justify-between">
                     <h3 className="text-xl font-semibold text-secondary-900">AI Lead Engagement Demo</h3>
                      <div className="flex items-center translate-y-[4px]">
                        <ArrowRight className="w-5 h-5 text-primary-600 group-hover:translate-x-1 transition-transform" />
                      </div>
                    </div>
                    <p className="text-secondary-600 mt-2">
                      Experience our intelligent lead engagement and nurturing system that qualifies leads and guides them through personalized conversion journeys.
                    </p>
                  </div>
                </div>
              </a>

              <a 
                href="/ai-phone-assistant-demo"
                className="group block bg-white/80 backdrop-blur-sm rounded-2xl p-6 border border-primary-100/50 shadow-soft hover:shadow-lg hover:-translate-y-0.5 transition-all"
                style={{ position: 'relative' }}
              >
                <div className="absolute top-0 right-0 px-3 py-1.5 bg-primary-50 text-primary-700 text-sm font-medium rounded-bl-lg border-l border-b border-primary-100">
                  Interactive Demo
                </div>
                <div className="flex items-start gap-6">
                  <div className="w-16 h-16 rounded-xl bg-primary-50 flex items-center justify-center group-hover:scale-105 transition-transform">
                    <Phone className="w-8 h-8 text-primary-600" />
                  </div>
                  <div className="flex-1">
                    <div className="flex items-center justify-between">
                      <h3 className="text-xl font-semibold text-secondary-900">AI Phone Assistant Demo</h3>
                      <div className="flex items-center translate-y-[4px]">
                        <ArrowRight className="w-5 h-5 text-primary-600 group-hover:translate-x-1 transition-transform" />
                      </div>
                    </div>
                    <p className="text-secondary-600 mt-2">
                      Experience our intelligent phone system that handles calls, routes inquiries, and provides 24/7 support.
                    </p>
                  </div>
                </div>
              </a>
              </div>

              {/* Custom Solutions Section */}
              <div
                className="group bg-white/80 backdrop-blur-sm rounded-3xl p-8 border border-primary-100/50 shadow-soft hover:shadow-lg transition-all mt-4"
              >
                <div className="flex items-start gap-6">
                  <div className="w-16 h-16 rounded-xl bg-primary-50 flex items-center justify-center group-hover:scale-105 transition-transform">
                    <Rocket className="w-8 h-8 text-primary-600" />
                  </div>
                  <div className="flex-1">
                    <div>
                      <h3 className="text-xl font-semibold text-secondary-900 mb-2">Custom Solutions</h3>
                      <p className="text-secondary-600 mb-6">
                        Need something unique? Let's discuss your project requirements and build a custom solution tailored to your business.
                      </p>
                      
                      <div className="space-y-4">
                        <div className="flex items-center gap-3 text-sm">
                          <div className="w-8 h-8 rounded-lg bg-primary-50 flex items-center justify-center text-primary-600">
                            <Layout className="w-4 h-4" />
                          </div>
                          <span className="text-secondary-700">Custom Builds & Integrations</span>
                        </div>
                        <div className="flex items-center gap-3 text-sm">
                          <div className="w-8 h-8 rounded-lg bg-primary-50 flex items-center justify-center text-primary-600">
                            <Bot className="w-4 h-4" />
                          </div>
                          <span className="text-secondary-700">Personalized AI Solutions</span>
                        </div>
                        <div className="flex items-center gap-3 text-sm">
                          <div className="w-8 h-8 rounded-lg bg-primary-50 flex items-center justify-center text-primary-600">
                            <Target className="w-4 h-4" />
                          </div>
                          <span className="text-secondary-700">Tailored Automation Workflows</span>
                        </div>
                      </div>
                      
                      <div className="mt-8">
                        <Link
                          to="/book-demo"
                          className="btn-primary inline-flex items-center gap-2"
                        >
                          Discuss Your Project
                          <ArrowRight className="w-5 h-5 group-hover:translate-x-0.5 transition-transform" />
                        </Link>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
        </div>
        <Footer />
      </div>
  );
};

export default Demo;